﻿using System;
using System.Collections.Generic;
using System.Text;

namespace ELTE.Basics.CoffeeShop
{
    /// <summary>
    /// Rendelés elem típusa.
    /// </summary>
    abstract class Item
    {
        /// <summary>
        /// Nettó érték lekérdezése.
        /// </summary>
        public virtual Int32 NetValue { get { return Convert.ToInt32(GrossValue * 0.8); } } // a bruttóból számoljuk a nettót
        /// <summary>
        /// Bruttó érték lekérdezése.
        /// </summary>
        public abstract Int32 GrossValue { get; }
        /// <summary>
        /// Típus lekérdezése.
        /// </summary>
        public abstract Char Type { get; }
        /// <summary>
        /// Név lekérdezése.
        /// </summary>
        public abstract String Name { get; }
    }

    /// <summary>
    /// Hamburger típusa.
    /// </summary>
    class Hamburger : Item
    {
        private Int32 _GrossValue;
        private String _Name;

        /// <summary>
        /// Bruttó érték lekérdezése.
        /// </summary>
        public override Int32 GrossValue
        {
            get { return _GrossValue; }
        }
        /// <summary>
        /// Típus lekérdezése.
        /// </summary>
        public override Char Type
        {
            get { return 'h'; }
        }
        /// <summary>
        /// Név lekérdezése.
        /// </summary>
        public override String Name
        {
            get { return _Name + " hamburger"; }
        }

        public Hamburger(String n, Int32 v) { _GrossValue = v; _Name = n; }
    }

    /// <summary>
    /// Ufó típusa.
    /// </summary>
    class Ufo : Item
    {
        private Int32 _GrossValue;
        private String _Name;

        /// <summary>
        /// Bruttó érték lekérdezése.
        /// </summary>
        public override Int32 GrossValue
        {
            get { return _GrossValue; }
        }
        /// <summary>
        /// Típus lekérdezése.
        /// </summary>
        public override Char Type
        {
            get { return 'u'; }
        }
        /// <summary>
        /// Név lekérdezése.
        /// </summary>
        public override String Name
        {
            get { return _Name + " ufo"; }
        }

        public Ufo(String n, Int32 v) { _GrossValue = v; _Name = n; }
    }

    /// <summary>
    /// Palacsinta típusa.
    /// </summary>
    class Pancake : Item
    {
        private Int32 _GrossValue;
        private String _Name;

        /// <summary>
        /// Bruttó érték lekérdezése.
        /// </summary>
        public override Int32 GrossValue
        {
            get { return _GrossValue; }
        }
        /// <summary>
        /// Típus lekérdezése.
        /// </summary>
        public override Char Type
        {
            get { return 'p'; }
        }
        /// <summary>
        /// Név lekérdezése.
        /// </summary>
        public override String Name
        {
            get { return _Name + " palacsinta"; }
        }

        public Pancake(String n, Int32 v) { _GrossValue = v; _Name = n; }
    }

    /// <summary>
    /// Tea típusa.
    /// </summary>
    class Tea : Item
    {
        /// <summary>
        /// Bruttó érték lekérdezése.
        /// </summary>
        public override Int32 GrossValue
        {
            get { return 200; }
        }
        /// <summary>
        /// Típus lekérdezése.
        /// </summary>
        public override Char Type
        {
            get { return 't'; }
        }
        /// <summary>
        /// Név lekérdezése.
        /// </summary>
        public override String Name
        {
            get { return "Tea"; }
        }
    }

    /// <summary>
    /// Narancs típusa.
    /// </summary>
    class Orange : Item
    {
        /// <summary>
        /// Bruttó érték lekérdezése.
        /// </summary>
        public override Int32 GrossValue
        {
            get { return 300; }
        }
        /// <summary>
        /// Típus lekérdezése.
        /// </summary>
        public override Char Type
        {
            get { return 'n'; }
        }
        /// <summary>
        /// Név lekérdezése.
        /// </summary>
        public override String Name
        {
            get { return "Narancs"; }
        }
    }

    /// <summary>
    /// Kóla típusa.
    /// </summary>
    class Coke : Item
    {
        /// <summary>
        /// Bruttó érték lekérdezése.
        /// </summary>
        public override Int32 GrossValue
        {
            get { return 250; }
        }
        /// <summary>
        /// Típus lekérdezése.
        /// </summary>
        public override Char Type
        {
            get { return 'k'; }
        }
        /// <summary>
        /// Név lekérdezése.
        /// </summary>
        public override String Name
        {
            get { return "Kóla"; }
        }
    }


}
