﻿using System;
using System.Collections.Generic;
using System.Text;

namespace ELTE.Basics.CoffeeShop
{
    /// <summary>
    /// Rendelés típusa.
    /// </summary>
    class Order
    {
        private Int32 _Number;
        private Int32 _CardNumber;
        private List<Item> _Items;

        /// <summary>
        /// Rendelés sorszámának elkérdezése.
        /// </summary>
        public Int32 Number { get { return _Number; } }
        /// <summary>
        /// Törzsvásárlói kártya számának lekérdezése.
        /// </summary>
        public Int32 CardNumber { get { return _CardNumber; } }
        /// <summary>
        /// Elemek számának lekrédezése.
        /// </summary>
        public Int32 ItemCount { get { return _Items.Count; } }
        /// <summary>
        /// Nettó érték lekérdezése.
        /// </summary>
        public Int32 NetValue
        {
            get
            {
                Int32 val = 0;
                for (Int32 i = 0; i < _Items.Count; i++)
                {
                    val += _Items[i].NetValue;
                }
                return val;
            }
        }
        /// <summary>
        /// Bruttó érték lekérdezése.
        /// </summary>
        public Int32 GrossValue
        {
            get
            {
                Int32 val = 0;
                for (Int32 i = 0; i < _Items.Count; i++)
                {
                    val += _Items[i].GrossValue;
                }
                return val;
            }
        }
        /// <summary>
        /// Rendeléselem lekérdezése.
        /// </summary>
        /// <param name="number">Elem sorszáma.</param>
        /// <returns></returns>
        public Item this[Int32 number]
        {
            get 
            { 
                if (number >= 0 && number < _Items.Count)
                {
                    return _Items[number];
                }
                else
                {
                    throw new IndexOutOfRangeException();
                }
            }
        }

        /// <summary>
        /// Rendelés létrehozása.
        /// </summary>
        /// <param name="number">Rendelés sorszáma.</param>
        /// <param name="cardNumber">Törzsvásárlói kártya száma.</param>
        public Order(Int32 number, Int32 cardNumber)
        {
            _Number = number;
            _CardNumber = cardNumber;
            _Items = new List<Item>();
        }
        /// <summary>
        /// Új elem felvétele.
        /// </summary>
        /// <param name="item">Rendelési elem.</param>
        public void AddItem(Item item)
        {
            _Items.Add(item);
        }
    }
}
